bayespy.inference.vmp.nodes.dirichlet.DirichletMoments.get_converter
====================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.dirichlet

.. automethod:: DirichletMoments.get_converter